# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from apitax.api.models.base_model_ import Model
from apitax.api.models.user_auth import UserAuth  # noqa: F401,E501
from apitax.api import util


class AuthResponse(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, status=None, message=None, access_token=None, refresh_token=None, auth=None):  # noqa: E501
        """AuthResponse - a model defined in Swagger

        :param status: The status of this AuthResponse.  # noqa: E501
        :type status: int
        :param message: The message of this AuthResponse.  # noqa: E501
        :type message: str
        :param access_token: The access_token of this AuthResponse.  # noqa: E501
        :type access_token: str
        :param refresh_token: The refresh_token of this AuthResponse.  # noqa: E501
        :type refresh_token: str
        :param auth: The auth of this AuthResponse.  # noqa: E501
        :type auth: UserAuth
        """
        self.swagger_types = {
            'status': int,
            'message': str,
            'access_token': str,
            'refresh_token': str,
            'auth': UserAuth
        }

        self.attribute_map = {
            'status': 'status',
            'message': 'message',
            'access_token': 'access_token',
            'refresh_token': 'refresh_token',
            'auth': 'auth'
        }

        self._status = status
        self._message = message
        self._access_token = access_token
        self._refresh_token = refresh_token
        self._auth = auth

    @classmethod
    def from_dict(cls, dikt):
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The AuthResponse of this AuthResponse.  # noqa: E501
        :rtype: AuthResponse
        """
        return util.deserialize_model(dikt, cls)

    @property
    def status(self):
        """Gets the status of this AuthResponse.


        :return: The status of this AuthResponse.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AuthResponse.


        :param status: The status of this AuthResponse.
        :type status: int
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def message(self):
        """Gets the message of this AuthResponse.


        :return: The message of this AuthResponse.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AuthResponse.


        :param message: The message of this AuthResponse.
        :type message: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def access_token(self):
        """Gets the access_token of this AuthResponse.


        :return: The access_token of this AuthResponse.
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this AuthResponse.


        :param access_token: The access_token of this AuthResponse.
        :type access_token: str
        """

        self._access_token = access_token

    @property
    def refresh_token(self):
        """Gets the refresh_token of this AuthResponse.


        :return: The refresh_token of this AuthResponse.
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this AuthResponse.


        :param refresh_token: The refresh_token of this AuthResponse.
        :type refresh_token: str
        """

        self._refresh_token = refresh_token

    @property
    def auth(self):
        """Gets the auth of this AuthResponse.


        :return: The auth of this AuthResponse.
        :rtype: UserAuth
        """
        return self._auth

    @auth.setter
    def auth(self, auth):
        """Sets the auth of this AuthResponse.


        :param auth: The auth of this AuthResponse.
        :type auth: UserAuth
        """

        self._auth = auth



#!/usr/bin/env python

import connexion

from apitax.api import encoder
from flask_jwt_extended import JWTManager

from apitaxcore.models.State import State

from flask import redirect, Response

app = connexion.App(__name__, specification_dir='./swagger/')
app.app.json_encoder = encoder.JSONEncoder
app.add_api('swagger.yaml', arguments={'title': 'Apitax'})

app.app.config['JWT_SECRET_KEY'] = State.config.get("secret") # More config here: http://flask-jwt-extended.readthedocs.io/en/latest/options.html#configuration-options
jwt = JWTManager(app.app)

if State.config.get('allow-cors'):
    from flask_cors import CORS
    CORS(app.app)

@jwt.user_claims_loader
def add_claims_to_access_token(identity):
    return {
        'username': identity['username'],
        'role': identity['role']
    }


@jwt.unauthorized_loader
def unauthorized_loader(): # More types here: http://flask-jwt-extended.readthedocs.io/en/latest/changing_default_behavior.html
    return Response(status=401, response='You must login')


@jwt.invalid_token_loader
def invalid_token_loader(): # More types here: http://flask-jwt-extended.readthedocs.io/en/latest/changing_default_behavior.html
    return Response(status=401, response='You must login')


@jwt.expired_token_loader
def expired_token_loader(): # More types here: http://flask-jwt-extended.readthedocs.io/en/latest/changing_default_behavior.html
    return Response(status=401, response='You must login')


def redirectUnauthorized(page="login", code=303):
    return redirect(State.baseUrl + page, code=code)


def startDevServer(ip, port):
    app.run(port=port, host=ip, debug=False)



from apitaxcore.flow.LoadedDrivers import LoadedDrivers
from apitaxcore.models.Credentials import Credentials
from apitaxcore.drivers.Driver import Driver
from apitaxcore.flow.responses.ApitaxResponse import ApitaxResponse
import base64


class ApitaxAuthentication:

    @staticmethod
    def getBasicHttp(credentials: Credentials):
        temp = credentials.username + ':' + credentials.password
        return {'Authorization': 'Basic ' + base64.b64encode(temp.encode('utf-8'))}

    @staticmethod
    def getBearerHttp(credentials: Credentials):
        return {'Authorization': 'Bearer ' + credentials.token}

    @staticmethod
    def login(credentials):
        driver: Driver = LoadedDrivers.getAuthDriver()
        role = None
        if not driver.isDriverAuthenticatable():
            return None
        if driver.isApitaxAuthBasedOnApiAuth():
            # apiDriver = LoadedDrivers.getPrimaryDriver()
            apiDriver: Driver = driver

            if 'driver' in credentials.extra:
                apiDriver = LoadedDrivers.getDriver(credentials.extra['driver'])
            result: ApitaxResponse = apiDriver.authenticateApi(credentials)

            if not result.isStatusSuccess():
                return None

            role = driver.authenticateApitax(result.getResponseBody()['credentials'])
            if apiDriver.isApiTokenable():
                credentials.token = apiDriver.getApiToken(result)
        else:
            role = driver.authenticateApitax(credentials)

        if not role:
            return None
        return {"role": role, "credentials": credentials}



# coding: utf-8

# flake8: noqa
from __future__ import absolute_import
# import models into model package
from apitax.api.models.auth_response import AuthResponse
from apitax.api.models.command import Command
from apitax.api.models.error_response import ErrorResponse
from apitax.api.models.execute import Execute
from apitax.api.models.response import Response
from apitax.api.models.script import Script
from apitax.api.models.script_create import ScriptCreate
from apitax.api.models.script_delete import ScriptDelete
from apitax.api.models.script_rename import ScriptRename
from apitax.api.models.script_save import ScriptSave
from apitax.api.models.user import User
from apitax.api.models.user_auth import UserAuth
from apitax.api.models.user_create import UserCreate
from apitax.api.models.user_delete import UserDelete
from apitax.api.models.user_save import UserSave



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from apitax.api.models.base_model_ import Model
from apitax.api import util


class User(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, username=None, password=None, role=None):  # noqa: E501
        """User - a model defined in Swagger

        :param username: The username of this User.  # noqa: E501
        :type username: str
        :param password: The password of this User.  # noqa: E501
        :type password: str
        :param role: The role of this User.  # noqa: E501
        :type role: str
        """
        self.swagger_types = {
            'username': str,
            'password': str,
            'role': str
        }

        self.attribute_map = {
            'username': 'username',
            'password': 'password',
            'role': 'role'
        }

        self._username = username
        self._password = password
        self._role = role

    @classmethod
    def from_dict(cls, dikt):
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The User of this User.  # noqa: E501
        :rtype: User
        """
        return util.deserialize_model(dikt, cls)

    @property
    def username(self):
        """Gets the username of this User.


        :return: The username of this User.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this User.


        :param username: The username of this User.
        :type username: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this User.


        :return: The password of this User.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this User.


        :param password: The password of this User.
        :type password: str
        """

        self._password = password

    @property
    def role(self):
        """Gets the role of this User.


        :return: The role of this User.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this User.


        :param role: The role of this User.
        :type role: str
        """

        self._role = role



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from apitax.api.models.base_model_ import Model
from apitax.api.models.script import Script  # noqa: F401,E501
from apitax.api import util


class ScriptRename(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, original=None, new=None):  # noqa: E501
        """ScriptRename - a model defined in Swagger

        :param original: The original of this ScriptRename.  # noqa: E501
        :type original: Script
        :param new: The new of this ScriptRename.  # noqa: E501
        :type new: Script
        """
        self.swagger_types = {
            'original': Script,
            'new': Script
        }

        self.attribute_map = {
            'original': 'original',
            'new': 'new'
        }

        self._original = original
        self._new = new

    @classmethod
    def from_dict(cls, dikt):
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The script_rename of this ScriptRename.  # noqa: E501
        :rtype: ScriptRename
        """
        return util.deserialize_model(dikt, cls)

    @property
    def original(self):
        """Gets the original of this ScriptRename.


        :return: The original of this ScriptRename.
        :rtype: Script
        """
        return self._original

    @original.setter
    def original(self, original):
        """Sets the original of this ScriptRename.


        :param original: The original of this ScriptRename.
        :type original: Script
        """
        if original is None:
            raise ValueError("Invalid value for `original`, must not be `None`")  # noqa: E501

        self._original = original

    @property
    def new(self):
        """Gets the new of this ScriptRename.


        :return: The new of this ScriptRename.
        :rtype: Script
        """
        return self._new

    @new.setter
    def new(self, new):
        """Sets the new of this ScriptRename.


        :param new: The new of this ScriptRename.
        :type new: Script
        """
        if new is None:
            raise ValueError("Invalid value for `new`, must not be `None`")  # noqa: E501

        self._new = new



# coding: utf-8

from __future__ import absolute_import

from flask import json
from six import BytesIO

from apitax.api.models.auth_response import AuthResponse  # noqa: E501
from apitax.api.models.error_response import ErrorResponse  # noqa: E501
from apitax.api.models.response import Response  # noqa: E501
from apitax.api.models.user_auth import UserAuth  # noqa: E501
from apitax.api.models.user_create import UserCreate  # noqa: E501
from apitax.api.models.user_delete import UserDelete  # noqa: E501
from apitax.api.models.user_save import UserSave  # noqa: E501
from apitax.api.test import BaseTestCase


class TestApitaxController(BaseTestCase):
    """ApitaxController integration test stubs"""

    def test_authenticate(self):
        """Test case for authenticate

        Authenticate
        """
        user = UserAuth()
        response = self.client.open(
            '/apitax/2/apitax/auth',
            method='POST',
            data=json.dumps(user),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_user(self):
        """Test case for create_user

        Create a new user
        """
        user_create = UserCreate()
        response = self.client.open(
            '/apitax/2/drivers/{driver}/apitax/users/{user}'.format(user='user_example', driver='driver_example'),
            method='POST',
            data=json.dumps(user_create),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_delete_user(self):
        """Test case for delete_user

        Delete a user
        """
        user_delete = UserDelete()
        response = self.client.open(
            '/apitax/2/drivers/{driver}/apitax/users/{user}'.format(user='user_example', driver='driver_example'),
            method='DELETE',
            data=json.dumps(user_delete),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_config(self):
        """Test case for get_config

        Retrieve the system config
        """
        response = self.client.open(
            '/apitax/2/apitax/config',
            method='GET')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_log(self):
        """Test case for get_log

        Retrieve the logs
        """
        response = self.client.open(
            '/apitax/2/apitax/logs/{log}'.format(log='log_example'),
            method='GET')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_user(self):
        """Test case for get_user

        Retrieve a user
        """
        response = self.client.open(
            '/apitax/2/drivers/{driver}/apitax/users/{user}'.format(user='user_example', driver='driver_example'),
            method='GET',
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_user_list(self):
        """Test case for get_user_list

        Retrieve a list of users
        """
        response = self.client.open(
            '/apitax/2/drivers/{driver}/apitax/users'.format(driver='driver_example'),
            method='GET',
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_refresh_token(self):
        """Test case for refresh_token

        Refreshes login token using refresh token
        """
        response = self.client.open(
            '/apitax/2/apitax/auth/refresh',
            method='POST')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_save_user(self):
        """Test case for save_user

        Save a user
        """
        user_save = UserSave()
        response = self.client.open(
            '/apitax/2/drivers/{driver}/apitax/users/{user}'.format(user='user_example', driver='driver_example'),
            method='PUT',
            data=json.dumps(user_save),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_system_status(self):
        """Test case for system_status

        Retrieve the system status
        """
        response = self.client.open(
            '/apitax/2/apitax/status',
            method='GET')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    import unittest
    unittest.main()



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='Apitax',
    packages=find_packages(),  # this must be the same as the name above
    version='3.0.1',
    description='Brings together Commandtax, Scriptax, Standard Library, and the API to create a powerful automation framework. Please use StarterPack to quickly incorporate additional drivers, configuration, and custom code into Apitax.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Shawn Clake',
    author_email='shawn.clake@gmail.com',
    url='https://github.com/Apitax/Apitax',
    keywords=['restful', 'api', 'commandtax', 'scriptax'],
    include_package_data=True,
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
    install_requires=[
        'connexion == 1.1.15',
        'flask-jwt-extended',
        'flask-cors',
        'python_dateutil == 2.6.0',
        'typing == 3.5.2.2',
        'setuptools >= 21.0.0',
        'apitaxcore==3.0.6',     # Core
        'commandtax==0.0.8',     # Commandtax Support
        'scriptax==0.0.4',       # Scriptax Support (.ah)
        'scriptaxstd==0.0.5',    # Scriptax STD Lib
        'apitaxdrivers==0.0.10',  # Misc Drivers (ie. Github connectivity)
    ],
)



from apitaxcore.models.State import State
from apitax.api.utilities.Roles import hasAccess as roleAccess

from apitax.api.models.error_response import ErrorResponse

from flask import redirect
from flask_jwt_extended import (create_access_token, create_refresh_token, jwt_required, jwt_refresh_token_required,
                                get_jwt_identity, get_raw_jwt, get_jwt_claims)


def hasAccess(role='admin'):
    if (roleAccess(get_jwt_identity(), role)):
        return True
    return False

def errorIfUnauthorized(role='admin', message='Your role does not allow you access to this'):
    if not hasAccess(role):
        return ErrorResponse(status=401, message=message)
    return False

def redirectIfUnauthorized(role='admin', page="login", code=303):
    if not hasAccess(role):
        return redirect(State.baseUrl + page, code=code)
    return False



from apitaxcore.catalog.Catalog import Catalog


class EndpointCatalog(Catalog):

    def __init__(self):
        super().__init__("endpoints")

    def add(self, name, label, value, summary='', help='', driver='', examples=[]):
        item = {name: {'label': label, 'value': value, 'summary': summary, 'help': help, 'driver': driver,
                       'examples': examples}}
        super().add(item)



#!/usr/bin/env python

import connexion

from apitax.api import encoder


def main():
    app = connexion.App(__name__, specification_dir='./swagger/')
    app.app.json_encoder = encoder.JSONEncoder
    app.add_api('swagger.yaml', arguments={'title': 'Apitax'})
    app.run(port=5080)


if __name__ == '__main__':
    main()
